@@ -23,7 +23,7 @@
 import os
 import sys
 from fcntl import ioctl
-from ctypes import c_uint32, c_uint8, c_uint16, c_char, POINTER, Structure, Array, Union, create_string_buffer, string_at
+from ctypes import c_uint32, c_uint8, c_uint16, c_ulong, c_char, POINTER, Structure, Array, Union, create_string_buffer, string_at
 
 
 # Commands from uapi/linux/i2c-dev.h
@@ -153,6 +153,9 @@ class i2c_smbus_ioctl_data(Structure):
 
 class i2c_msg(Structure):
     """
+    Represents a single I2C message for read or write operations.
+    This is the expected data container for :py:meth:`SMBus.i2c_rdwr`.
+
     As defined in ``i2c.h``.
     """
     _fields_ = [
@@ -212,7 +215,7 @@ class i2c_msg(Structure):
         :param address: Slave address.
         :type address: int
         :param buf: Bytes to write. Either list of values or str.
-        :type buf: list
+        :type buf: bytes or str or list
         :return: New :py:class:`i2c_msg` instance for write operation.
         :rtype: :py:class:`i2c_msg`
         """
@@ -247,7 +250,7 @@ class i2c_rdwr_ioctl_data(Structure):
         be called with ``ioctl(fd, I2C_RDWR, data)``.
 
         :param i2c_msg_instances: Up to 42 i2c_msg instances
-        :rtype: i2c_rdwr_ioctl_data
+        :rtype: :py:class:`i2c_rdwr_ioctl_data`
         """
         n_msg = len(i2c_msg_instances)
         msg_array = (i2c_msg * n_msg)(*i2c_msg_instances)
@@ -261,6 +264,9 @@ class i2c_rdwr_ioctl_data(Structure):
 
 
 class SMBus(object):
+    """
+    Main class for I2C and SMBus communication, providing all IO functions for device access.
+    """
 
     def __init__(self, bus=None, force=False):
         """
@@ -270,9 +276,8 @@ class SMBus(object):
             or an absolute file path (e.g. `/dev/i2c-42`).
             If not given, a subsequent  call to ``open()`` is required.
         :type bus: int or str
-        :param force: force using the slave address even when driver is
-            already using it.
-        :type force: boolean
+        :param force: Use slave address even when driver is already using it.
+        :type force: bool
         """
         self.fd = None
         self.funcs = I2cFunc(0)
@@ -329,7 +334,7 @@ class SMBus(object):
         Enable/Disable PEC (Packet Error Checking) - SMBus 1.1 and later
 
         :param enable:
-        :type enable: Boolean
+        :type enable: bool
         """
         if not (self.funcs & I2cFunc.SMBUS_PEC):
             raise IOError('SMBUS_PEC is not a feature')
@@ -345,8 +350,8 @@ class SMBus(object):
 
         :param address:
         :type address: int
-        :param force:
-        :type force: Boolean
+        :param force: Use slave address even when driver is already using it.
+        :type force: bool
         """
         force = force if force is not None else self.force
         if self.address != address or self._force_last != force:
@@ -359,11 +364,15 @@ class SMBus(object):
 
     def _get_funcs(self):
         """
-        Returns a 32-bit value stating supported I2C functions.
+        Returns a value stating supported I2C functions.
 
         :rtype: int
         """
-        f = c_uint32()
+        # Use c_ulong to match the kernel's expected "unsigned long *" type.
+        # This is 4 bytes on 32-bit systems and 8 bytes on 64-bit systems.
+        # Using c_uint32 on 64-bit systems causes buffer overflow errors
+        # in Python 3.14+ due to stricter ctypes buffer size checks.
+        f = c_ulong()
         ioctl(self.fd, I2C_FUNCS, f)
         return f.value
 
@@ -372,8 +381,8 @@ class SMBus(object):
         Perform quick transaction. Throws IOError if unsuccessful.
         :param i2c_addr: i2c address
         :type i2c_addr: int
-        :param force:
-        :type force: Boolean
+        :param force: Use slave address even when driver is already using it.
+        :type force: bool
         """
         self._set_address(i2c_addr, force=force)
         msg = i2c_smbus_ioctl_data.create(
@@ -387,8 +396,8 @@ class SMBus(object):
         :rtype: int
         :param i2c_addr: i2c address
         :type i2c_addr: int
-        :param force:
-        :type force: Boolean
+        :param force: Use slave address even when driver is already using it.
+        :type force: bool
         :return: Read byte value
         """
         self._set_address(i2c_addr, force=force)
@@ -406,8 +415,8 @@ class SMBus(object):
         :type i2c_addr: int
         :param value: value to write
         :type value: int
-        :param force:
-        :type force: Boolean
+        :param force: Use slave address even when driver is already using it.
+        :type force: bool
         """
         self._set_address(i2c_addr, force=force)
         msg = i2c_smbus_ioctl_data.create(
@@ -423,8 +432,8 @@ class SMBus(object):
         :type i2c_addr: int
         :param register: Register to read
         :type register: int
-        :param force:
-        :type force: Boolean
+        :param force: Use slave address even when driver is already using it.
+        :type force: bool
         :return: Read byte value
         :rtype: int
         """
@@ -445,8 +454,8 @@ class SMBus(object):
         :type register: int
         :param value: Byte value to transmit
         :type value: int
-        :param force:
-        :type force: Boolean
+        :param force: Use slave address even when driver is already using it.
+        :type force: bool
         :rtype: None
         """
         self._set_address(i2c_addr, force=force)
@@ -464,8 +473,8 @@ class SMBus(object):
         :type i2c_addr: int
         :param register: Register to read
         :type register: int
-        :param force:
-        :type force: Boolean
+        :param force: Use slave address even when driver is already using it.
+        :type force: bool
         :return: 2-byte word
         :rtype: int
         """
@@ -486,8 +495,8 @@ class SMBus(object):
         :type register: int
         :param value: Word value to transmit
         :type value: int
-        :param force:
-        :type force: Boolean
+        :param force: Use slave address even when driver is already using it.
+        :type force: bool
         :rtype: None
         """
         self._set_address(i2c_addr, force=force)
@@ -507,8 +516,8 @@ class SMBus(object):
         :type register: int
         :param value: Word value to transmit
         :type value: int
-        :param force:
-        :type force: Boolean
+        :param force: Use slave address even when driver is already using it.
+        :type force: bool
         :rtype: int
         """
         self._set_address(i2c_addr, force=force)
@@ -527,8 +536,8 @@ class SMBus(object):
         :type i2c_addr: int
         :param register: Start register
         :type register: int
-        :param force:
-        :type force: Boolean
+        :param force: Use slave address even when driver is already using it.
+        :type force: bool
         :return: List of bytes
         :rtype: list
         """
@@ -550,8 +559,8 @@ class SMBus(object):
         :type register: int
         :param data: List of bytes
         :type data: list
-        :param force:
-        :type force: Boolean
+        :param force: Use slave address even when driver is already using it.
+        :type force: bool
         :rtype: None
         """
         length = len(data)
@@ -576,8 +585,8 @@ class SMBus(object):
         :type register: int
         :param data: List of bytes
         :type data: list
-        :param force:
-        :type force: Boolean
+        :param force: Use slave address even when driver is already using it.
+        :type force: bool
         :return: List of bytes
         :rtype: list
         """
@@ -604,8 +613,8 @@ class SMBus(object):
         :type register: int
         :param length: Desired block length
         :type length: int
-        :param force:
-        :type force: Boolean
+        :param force: Use slave address even when driver is already using it.
+        :type force: bool
         :return: List of bytes
         :rtype: list
         """
@@ -629,8 +638,8 @@ class SMBus(object):
         :type register: int
         :param data: List of bytes
         :type data: list
-        :param force:
-        :type force: Boolean
+        :param force: Use slave address even when driver is already using it.
+        :type force: bool
         :rtype: None
         """
         length = len(data)
